==> wow_views-0.0.66.tar.gz: lib/screens/dem_nguoc_thoi_gian/count_downt_su_kien.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/screens/dem_nguoc_thoi_gian/dem_nguoc_thoi_gian.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class CountDowntSuKien extends StatefulWidget {
  const CountDowntSuKien({Key? key, this.data}) : super(key: key);
  final Map<String, Object?>? data;

  @override
  State<CountDowntSuKien> createState() => _CountDowntSuKienState();
}

class _CountDowntSuKienState extends State<CountDowntSuKien> {
  DateTime? thoiGianBatDauDangKy;
  DateTime? thoiGianKetThucDangKy;
  DateTime? thoiGianBatDauSuKien;
  DateTime? thoiGianKetThucSuKien;

  @override
  void initState() {
    thoiGianBatDauDangKy =
        Methods.getDateTime(widget.data, 'thoiGianBatDauDangKy');
    thoiGianKetThucDangKy =
        Methods.getDateTime(widget.data, 'thoiGianKetThucDangKy');
    thoiGianBatDauSuKien = Methods.getDateTime(widget.data, 'tgDienRaTu');
    thoiGianKetThucDangKy = Methods.getDateTime(widget.data, 'tgDienRaDen');
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    DateTime now = DateTime.now();
    try {
      //Tính thời gian đần ngày đăng ký
      if (thoiGianBatDauDangKy != null && now.isBefore(thoiGianBatDauDangKy!)) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_DANG_KY_NGAY_SAU'),
          child: DemNguocThoigGian(
            endTime: thoiGianBatDauDangKy,
            hetThoiGian: ()=>setState(() {}),
          ),
        );
        //Tính thời gian hết hạn dăng ký
      } else if (thoiGianBatDauDangKy != null && thoiGianKetThucDangKy!=null &&
          thoiGianBatDauDangKy!.isBefore(now) &&
          now.isBefore(thoiGianKetThucDangKy!)) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_HET_THOI_GIAN_DANG_KY_SAU'),
          child: DemNguocThoigGian(
            endTime: thoiGianKetThucDangKy,
            hetThoiGian: ()=>setState(() {})
          ),
        );
        //Tính thời gian bắt đầu sự kiện
      } else if (thoiGianBatDauSuKien != null &&
          now.isBefore(thoiGianBatDauSuKien!)) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_SU_KIEN_SE_BAT_DAU_SAU'),
          child: DemNguocThoigGian(endTime: thoiGianBatDauSuKien,
          hetThoiGian: ()=>setState(() {})),
        );
        // Thời gian kết thúc sự kiện
      } else if (thoiGianBatDauSuKien != null && thoiGianKetThucSuKien!=null &&
          thoiGianBatDauSuKien!.isBefore(now) ) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_KET_THUC_SAU'),
          child: DemNguocThoigGian(
            endTime: thoiGianKetThucSuKien,
            hetThoiGian: ()=>setState(() {})
          ),
        );
      }
    } catch (e) {
      return Container();
    }
    return Container();
  }

  Widget _thongBao({required String text,required Widget child}){
    return Row(
      children: [
        Expanded(child: Text(text)),
        const SizedBox(width: 4,),
        child
      ],
    );
  }

}

==> wow_views-0.0.69.tar.gz: lib/screens/dem_nguoc_thoi_gian/count_downt_su_kien.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/screens/dem_nguoc_thoi_gian/dem_nguoc_thoi_gian.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class CountDowntSuKien extends StatefulWidget {
  const CountDowntSuKien({Key? key, this.data}) : super(key: key);
  final Map<String, Object?>? data;

  @override
  State<CountDowntSuKien> createState() => _CountDowntSuKienState();
}

class _CountDowntSuKienState extends State<CountDowntSuKien> {
  DateTime? thoiGianBatDauDangKy;
  DateTime? thoiGianKetThucDangKy;
  DateTime? thoiGianBatDauSuKien;
  DateTime? thoiGianKetThucSuKien;

  @override
  void initState() {
    thoiGianBatDauDangKy =
        Methods.getDateTime(widget.data, 'thoiGianBatDauDangKy');
    thoiGianKetThucDangKy =
        Methods.getDateTime(widget.data, 'thoiGianKetThucDangKy');
    thoiGianBatDauSuKien = Methods.getDateTime(widget.data, 'tgDienRaTu');
    thoiGianKetThucSuKien = Methods.getDateTime(widget.data, 'tgDienRaDen');
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    DateTime now = DateTime.now();
    try {
      //Tính thời gian đần ngày đăng ký
      if (thoiGianBatDauDangKy != null && now.isBefore(thoiGianBatDauDangKy!)) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_DANG_KY_NGAY_SAU'),
          child: DemNguocThoigGian(
            endTime: thoiGianBatDauDangKy,
            hetThoiGian: ()=>setState(() {}),
          ),
        );
        //Tính thời gian hết hạn dăng ký
      } else if (thoiGianBatDauDangKy != null && thoiGianKetThucDangKy!=null &&
          thoiGianBatDauDangKy!.isBefore(now) &&
          now.isBefore(thoiGianKetThucDangKy!)) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_HET_THOI_GIAN_DANG_KY_SAU'),
          child: DemNguocThoigGian(
            endTime: thoiGianKetThucDangKy,
            hetThoiGian: ()=>setState(() {})
          ),
        );
        //Tính thời gian bắt đầu sự kiện
      } else if (thoiGianBatDauSuKien != null &&
          now.isBefore(thoiGianBatDauSuKien!)) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_SU_KIEN_SE_BAT_DAU_SAU'),
          child: DemNguocThoigGian(endTime: thoiGianBatDauSuKien,
          hetThoiGian: ()=>setState(() {})),
        );
        // Thời gian kết thúc sự kiện
      } else if (thoiGianBatDauSuKien != null && thoiGianKetThucSuKien!=null &&
          thoiGianBatDauSuKien!.isBefore(now) ) {
        return _thongBao(
          text: Message.getMessage('SUKIEN_KET_THUC_SAU'),
          child: DemNguocThoigGian(
            endTime: thoiGianKetThucSuKien,
            hetThoiGian: ()=>setState(() {})
          ),
        );
      }
    } catch (e) {
      return Container();
    }
    return Container();
  }

  Widget _thongBao({required String text,required Widget child}){
    return Row(
      children: [
        Expanded(child: Text(text)),
        const SizedBox(width: 4,),
        child
      ],
    );
  }

}
